## VennProteomics

---

For creating venndiagram from gene names. VennProteomics also support reading in uniprot accession id and retrieve gene names from uniprot for the purpose of creating the venn-diagram.